/*
+-----------------------------------------------------------------------+
| Bullseye.mq4                                                          |
| Version 1.2                                                           |
| Raymond L. Tayse (Que)                                                |
| http://www.forexinc.net                                               |
+-----------------------------------------------------------------------+

+-----------------------------------------------------------------------+
| This indicator is for Moving Average Cross Systems using an RSI       |
| cross as well. You do not need to have the Moving Averages nor the    |
| RSI on your chart for this to work. This indicator already calculates |
| both the Moving Averages and the RSI values of your choosing.         |
|                                                                       |
| MA1:                                                                  |
|  This Moving Average should be on top when the cross is long.         |
|                                                                       |
| MA2:                                                                  |
|  This moving average should be on top when the cross is short.        |
|                                                                       |
| MAMethod Values:                                                      |
|  0 = Simple                                                           |
|  1 = Exponential                                                      |
|  2 = Smoothed                                                         |
|  3 = Linear Weighted                                                  |
|                                                                       |
| MAPeriod and RSIPeriod:                                               |
|  These are simply the period values for each indicator_buffers.       |
|                                                                       |
| RSIUpCross and RSIDownCross:                                          |
|  These are the up and down thresholds for your RSI cross. These       |
|  values can be the same (example RSI 50 cross up or down).            |
|                                                                       |
| Note*                                                                 |
|  This indicator only works for the timeframe selected. This means if  |
|  you want it to alert you on EURUSD on both H1 and H4, you must have  |
|  two charts open. One chart for EURUSD H1 and one for EURUSD H4.      |
+-----------------------------------------------------------------------+
*/ 

#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 100
#property indicator_buffers 6
#property indicator_color1 ForestGreen
#property indicator_color2 Brown
#property indicator_color3 ForestGreen
#property indicator_color4 Brown
#property indicator_color5 ForestGreen
#property indicator_color6 Brown
#property indicator_width1 1
#property indicator_width2 1
#property indicator_width3 1
#property indicator_width4 1
#property indicator_width5 1
#property indicator_width6 1

double CrossUp[];
double CrossDown[];
double BothUp[];
double BothDown[];
double RSIUp[];
double RSIDown[];

extern int MA1Method = 1;
extern int MA1Period = 5;
extern int MA2Method = 0;
extern int MA2Period = 8;
extern int RSIPeriod = 5;
extern int RSIUpCross = 80;
extern int RSIDownCross = 20;

extern bool BullseyeAlert = false;
extern bool BullseyeEmail = false;
extern bool CrossAlert = false;
extern bool CrossEmail = false;
extern bool RSIAlert = false;
extern bool RSIEmail = false;


int upalert1=false,downalert1=false;
int upalert2=false,downalert2=false;
int upalert3=false,downalert3=false;
//+------------------------------------------------------------------+
//| Custom indicator initialization function |
//+------------------------------------------------------------------+
int init()
{
//---- indicators
SetIndexStyle(0, DRAW_ARROW, EMPTY);
SetIndexArrow(0, 71);
SetIndexBuffer(0, CrossUp);
SetIndexStyle(1, DRAW_ARROW, EMPTY);
SetIndexArrow(1, 72);
SetIndexBuffer(1, CrossDown);
SetIndexStyle(2, DRAW_ARROW, EMPTY);
SetIndexArrow(2, 177);
SetIndexBuffer(2, BothUp);
SetIndexStyle(3, DRAW_ARROW, EMPTY);
SetIndexArrow(3, 177);
SetIndexBuffer(3, BothDown);
SetIndexStyle(4, DRAW_ARROW, EMPTY);
SetIndexArrow(4, 115);
SetIndexBuffer(4, RSIUp);
SetIndexStyle(5, DRAW_ARROW, EMPTY);
SetIndexArrow(5, 115);
SetIndexBuffer(5, RSIDown);
//----
return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function |
//+------------------------------------------------------------------+
int deinit()
{
//---- 
//----
return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function |
//+------------------------------------------------------------------+
int start()
{

   int limit, i, counter;
   
   double RSI, RSIp,MA1now, MA2now, MA1previous, MA2previous, MA1after, MA2after, MA1, MA2;

   static datetime prevtime = 0;

   int counted_bars=IndicatorCounted();

//---- check for possible errors

   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted

   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;

//---- start calculations

   for(i = 0; i <= limit; i++) 
   {

      if (MA1Method == 0) MA1 = MODE_SMA;
      if (MA1Method == 1) MA1 = MODE_EMA;
      if (MA1Method == 2) MA1 = MODE_SMMA;
      if (MA1Method == 3) MA1 = MODE_LWMA;
      if (MA2Method == 0) MA2 = MODE_SMA;
      if (MA2Method == 1) MA2 = MODE_EMA;
      if (MA2Method == 2) MA2 = MODE_SMMA;
      if (MA2Method == 3) MA2 = MODE_LWMA;
      

      MA1now = iMA(NULL, 0, MA1Period, 0, MA1, PRICE_CLOSE, i);
      MA1previous = iMA(NULL, 0, MA1Period, 0, MA1, PRICE_CLOSE, i+1);
      MA1after = iMA(NULL, 0, MA1Period, 0, MA1, PRICE_CLOSE, i-1);
      MA2now = iMA(NULL, 0, MA2Period, 0, MA2, PRICE_CLOSE, i);
      MA2previous = iMA(NULL, 0, MA2Period, 0, MA2, PRICE_CLOSE, i+1);
      MA2after = iMA(NULL, 0, MA2Period, 0, MA2, PRICE_CLOSE, i-1);

      RSI=iRSI(NULL,0,RSIPeriod,PRICE_CLOSE,i);
      RSIp=iRSI(NULL,0,RSIPeriod,PRICE_CLOSE,i+1);

//---- alerts
      
      if (prevtime == Time[0])
      {
         return(0);
      }
      
      else
      {      
         if (((MA1now > MA2now) && (MA1previous < MA2previous) && (MA1after > MA2after)) &&  ( RSI > RSIUpCross && RSIp <= RSIUpCross))
         {
            BothUp[i] = 80;
            if(i<=2 && BullseyeAlert && !upalert1)
            {
               PlaySound("alert.wav");
               Alert (Symbol()," ",Period(),"M Bullseye UP");
            }
            if(i<=2 && BullseyeEmail && !upalert1)
            { 
               SendMail("Bullseye UP on "+Symbol(),"");
            }
            //upalert1=true;
            //downalert1=false;
         }


         if (((MA1now < MA2now) && (MA1previous > MA2previous) && (MA1after < MA2after)) && ( RSI < RSIDownCross && RSIp >= RSIDownCross))
         {
            BothDown[i] = 80;
            if(i<=2 && BullseyeAlert && !downalert1)
            {
               PlaySound("alert.wav"); //sell wav
               Alert (Symbol()," ",Period(),"M Bullseye DOWN");
            }
            if(i<=2 && BullseyeEmail && !downalert1)
            { 
               SendMail("Bullseye DOWN on "+Symbol(),"");
            }
            //upalert1=false;
            //downalert1=true;
         }


         if ((MA1now > MA2now) && (MA1previous < MA2previous) && (MA1after > MA2after))
         {
            CrossUp[i] = 50;
            if(i<=2 && CrossAlert && !upalert2)
            {
               PlaySound("alert.wav"); //sell wav
               Alert (Symbol()," ",Period(),"M MA Cross UP ");
            }
            if(i<=2 && CrossEmail && !upalert2)
            { 
               SendMail("MA Cross UP on "+Symbol(),"");
            }
            //upalert2=true;
            //downalert2=false;
         }


         if ((MA1now < MA2now) && (MA1previous > MA2previous) && (MA1after < MA2after))
         {
            CrossDown[i] = 50;
            if(i<=2 && CrossAlert && !downalert2)
            {
               PlaySound("alert.wav"); //sell wav
               Alert (Symbol()," ",Period(),"M MA Cross DOWN ");
            }
            if(i<=2 && CrossEmail && !downalert2)
            { 
               SendMail("MA Cross DOWN on "+Symbol(),"");
            }
            //upalert2=false;
            //downalert2=true;
         }


         if ( RSI > RSIUpCross && RSIp <= RSIUpCross)
         {
            RSIUp[i] = 20;
            if(i<=2 && RSIAlert && !upalert3)
            {
               PlaySound("alert.wav"); //sell wav
               Alert (Symbol()," ",Period(),"M RSI Cross UP ");
            }
            if(i<=2 && RSIEmail && !upalert3)
            { 
               SendMail("RSI Cross UP on "+Symbol(),"");
            }
            //upalert3=true;
            //downalert3=false;
         }


         if ( RSI < RSIDownCross && RSIp >= RSIDownCross)
         {
            RSIDown[i] = 20;
            if(i<=2 && RSIAlert && !downalert3)
            {
               PlaySound("alert.wav"); //sell wav
               Alert (Symbol()," ",Period(),"M RSI Cross DOWN ");
            }
            if(i<=2 && RSIEmail && !downalert3)
            { 
               SendMail("RSI Cross DOWN on "+Symbol(),"");
            }
            //upalert3=false;
            //downalert3=true;
         }

      }

   }

prevtime = Time[0];
   
return(0);

}

